@@ -68,7 +68,89 @@ def to_screaming_snake(subject):
     return to_snake_case(subject).upper()
 
 
-def leftPad(subject, max_len=2, pad_char='0'):
+def limit_length(subject, max_len=2, from_beginning=True):
+    '''
+        Limits the subject's character count to the max_len.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `subject` {str}
+            The subject to convert
+        `max_len` {int}
+            The maximum length of the subject, if >= max_len the subject will not be padded.
+
+        [`limit_length`=False] {bool}
+            If True the subject will have excess characters removed from the beginning or end.            
+        [`from_beginning`=True] {bool}
+            If True the subject will have excess characters removed from the beginning.\n
+            If False the subject will have excess characters removed from the end.
+
+        Return {str}
+        ----------------------
+        The formatted string
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 12-20-2021 14:48:31
+        `memberOf`: string_format
+        `version`: 1.0
+        `method_name`: limit_length
+    '''
+    subject = str(subject)
+    slen = len(subject)
+    if slen <= max_len:
+        return subject
+    else:
+        if from_beginning is True:
+            return subject[:max_len]
+        if from_beginning is False:
+            return subject[max_len:]
+
+
+def leftPad(subject, max_len=2, pad_char='0', limit_length=False, from_beginning=True):
+    '''
+        Convert a subject to snake case.
+
+        ----------
+        Arguments
+        -----------------
+        `subject` {str}
+            The subject to convert
+        `max_len` {int}
+            The maximum length of the subject, if >= max_len the subject will not be padded.
+        `pad_char` {str}
+            The character to pad the subject with
+
+        [`limit_length`=False] {bool}
+            If True the subject will have excess characters removed from the beginning or end.
+
+        [`from_beginning`=True] {bool}
+            If True the subject will have excess characters removed from the beginning.\n
+            If False the subject will have excess characters removed from the end.
+        Return
+        ----------
+        `return` {str}
+            The subject formatted with left padding
+
+        Example
+        ----------
+        leftPad("1",5,'0') // "00001"
+        leftPad("/esls_test/server_source/TEST.scss",15,' ',True,True) // "/esls_test/serv"
+        leftPad("/e/TEST.scss",15,' ',True,False) // "   /e/TEST.scss"
+    '''
+    if limit_length is True:
+        subject = limit_length(subject, max_len, from_beginning)
+    subject = str(subject)
+    slen = len(subject)
+    if slen <= max_len:
+        subject = f"{pad_char * (max_len - slen)}{subject}"
+    return subject
+
+
+def rightPad(subject, max_len=2, pad_char='0'):
     '''
         Convert a subject to snake case.
 
@@ -93,7 +175,7 @@ def leftPad(subject, max_len=2, pad_char='0'):
     subject = str(subject)
     slen = len(subject)
     if slen <= max_len:
-        subject = f"{pad_char * (max_len - slen)}{subject}"
+        subject = f"{subject}{pad_char * (max_len - slen)}"
     return subject
 
 
